from aiohttp import web
import aiohttp_jinja2
import jinja2

import pnpdevice.discovery
import pnpdevice.relays

def html(text: str) -> web.Response:
	return web.Response(content_type="text/html", text=f"<html>{text}</html>")

@aiohttp_jinja2.template("index.template.html")
async def index(request):
	relays = request.app["relays"]
	return {
		"relays": relays.relays_list(),
	}

@aiohttp_jinja2.template("relay-create.template.html")
async def relay_create_get(request: Request):
	"Get the form to create a new relay."
	relays = request.app["relays"]
	pins = relays.pins_list()
	return {"pins": pins}

async def relay_create_post(request: Request, chip_and_number: str, name: str):
	"Create a new relay."
	chip, number = chip_and_number.partition("-")
	LOGGER.info("Creating relay %s %s with name %s", chip, number, name)
	return RedirectResponse(status_code=303, url="/")

async def status(request: Request):
	return html("Status")

def run(relays: pnpdevice.relays.Relays):
	"Run the embedded web server"
	app = web.Application()
	app["relays"] = relays
	aiohttp_jinja2.setup(app,
	  loader=jinja2.FileSystemLoader("templates"))
	app.on_startup.append(pnpdevice.discovery.handle)
	app.add_routes([web.get("/", index)])
	app.add_routes([web.get("/relay/create", relay_create_get)])
	app.add_routes([web.post("/relay/create", relay_create_post)])
	web.run_app(app)

